Module: Gauge
- Defined in:
- lib/table.rb,
lib/api.pb.rb,
lib/spec.pb.rb,
lib/executor.rb,
lib/connector.rb,
lib/datastore.rb,
lib/code_parser.rb,
lib/messages.pb.rb,
lib/method_cache.rb,
lib/configuration.rb,
lib/gauge_runtime.rb,
lib/message_processor.rb,
lib/processors/execution_handler.rb,
lib/processors/kill_request_processor.rb,
lib/processors/datastore_init_processor.rb,
lib/processors/execution_hook_processors.rb,
lib/processors/step_name_request_processor.rb,
lib/processors/step_names_request_processor.rb,
lib/processors/execute_step_request_processor.rb,
lib/processors/refactor_step_request_processor.rb,
lib/processors/step_validation_request_processor.rb
Overview
You should have received a copy of the GNU General Public License along with Gauge-Ruby. If not, see http://www.gnu.org/licenses/.
Defined Under Namespace
Modules: Connector, Executor, Messages, Processors, Runtime Classes: CodeParser, Configuration, DataStore, DataStoreFactory, MessageProcessor, MethodCache, Table
Class Method Summary collapse
-
.configure(&block) ⇒ Object
Custom configuration for Gauge Lets you configure modules that need to be included at runtime.
Class Method Details
.configure(&block) ⇒ Object
Custom configuration for Gauge Lets you configure modules that need to be included at runtime.
40 41 42 |
# File 'lib/configuration.rb', line 40 def configure(&block) Configuration.instance.instance_eval &block end |